==> cobalt-0.0.1-sources.jar: it/auties/whatsapp/model/message/button/ListResponseMessageBuilder.java <==
package it.auties.whatsapp.model.message.button;

public class ListResponseMessageBuilder {
    private java.lang.String title;
    private it.auties.whatsapp.model.button.misc.SingleSelectReplyButton reply;
    private java.util.Optional<it.auties.whatsapp.model.info.ContextInfo> contextInfo;
    private java.util.Optional<java.lang.String> description;
    private it.auties.whatsapp.model.message.button.ListResponseMessage.Type listType;

    public ListResponseMessageBuilder() {
        title = null;
        reply = null;
        contextInfo = java.util.Optional.empty();
        description = java.util.Optional.empty();
        listType = null;
    }

    public ListResponseMessageBuilder title(java.lang.String title) {
        this.title = title;
        return this;
    }
    public ListResponseMessageBuilder reply(it.auties.whatsapp.model.button.misc.SingleSelectReplyButton reply) {
        this.reply = reply;
        return this;
    }
    public ListResponseMessageBuilder contextInfo(java.util.Optional<it.auties.whatsapp.model.info.ContextInfo> contextInfo) {
        this.contextInfo = contextInfo;
        return this;
    }
    public ListResponseMessageBuilder contextInfo(it.auties.whatsapp.model.info.ContextInfo contextInfo) {
        this.contextInfo = java.util.Optional.ofNullable(contextInfo);
        return this;
    }
    public ListResponseMessageBuilder description(java.util.Optional<java.lang.String> description) {
        this.description = description;
        return this;
    }
    public ListResponseMessageBuilder description(java.lang.String description) {
        this.description = java.util.Optional.ofNullable(description);
        return this;
    }
    public ListResponseMessageBuilder listType(it.auties.whatsapp.model.message.button.ListResponseMessage.Type listType) {
        this.listType = listType;
        return this;
    }

    public it.auties.whatsapp.model.message.button.ListResponseMessage build() {
        return new it.auties.whatsapp.model.message.button.ListResponseMessage(title, reply, contextInfo, description, listType);
    }
}

==> cobalt-0.0.3-sources.jar: it/auties/whatsapp/model/message/button/ListResponseMessageBuilder.java <==
package it.auties.whatsapp.model.message.button;

public class ListResponseMessageBuilder {
    private java.lang.String title;
    private it.auties.whatsapp.model.button.misc.SingleSelectReplyButton reply;
    private it.auties.whatsapp.model.info.ContextInfo contextInfo;
    private java.lang.String description;
    private it.auties.whatsapp.model.message.button.ListResponseMessage.Type listType;

    public ListResponseMessageBuilder() {
        title = null;
        reply = null;
        contextInfo = null;
        description = null;
        listType = null;
    }

    public ListResponseMessageBuilder title(java.lang.String title) {
        this.title = title;
        return this;
    }
    public ListResponseMessageBuilder reply(it.auties.whatsapp.model.button.misc.SingleSelectReplyButton reply) {
        this.reply = reply;
        return this;
    }
    public ListResponseMessageBuilder contextInfo(it.auties.whatsapp.model.info.ContextInfo contextInfo) {
        this.contextInfo = contextInfo;
        return this;
    }
    public ListResponseMessageBuilder description(java.lang.String description) {
        this.description = description;
        return this;
    }
    public ListResponseMessageBuilder listType(it.auties.whatsapp.model.message.button.ListResponseMessage.Type listType) {
        this.listType = listType;
        return this;
    }

    public it.auties.whatsapp.model.message.button.ListResponseMessage build() {
        return new it.auties.whatsapp.model.message.button.ListResponseMessage(title, reply, contextInfo, description, listType);
    }
}
